==> nextcloud-29.0.12.tgz: nextcloud/apps/dashboard/l10n/gl.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Taboleiro",
    "Dashboard app" : "Aplicación de taboleiro",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking." : "Comece o día informado\n\nO Taboleiro de Nextcloud é o seu punto de partida do día, onde atopará unha vista xeral das súas próximas citas, correos-e urxentes, mensaxes de parolas, billetes entrantes, chíos máis recentes e moito máis. A xente pode engadir os trebellos que lles gusten e cambiar o fondo ao seu antollo.",
    "\"{title} icon\"" : "«icona {title}»",
    "Customize" : "Personalizar",
    "Edit widgets" : "Editar trebellos",
    "Get more widgets from the App Store" : "Obter máis trebellos na tenda de aplicacións",
    "Weather service" : "Servizo meteorolóxico",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Para a súa privacidade, o servidor de Nextcloud solicita os datos meteorolóxicos no seu nome para que o servizo meteorolóxico non reciba información persoal.",
    "Weather data from Met.no" : "Datos meteorolóxicos de Met.no",
    "geocoding with Nominatim" : "xeocodificación con Nominatim",
    "elevation data from OpenTopoData" : "datos de elevación de OpenTopoData",
    "Weather" : "Meteoroloxía",
    "Status" : "Estado",
    "Good morning" : "Bos días",
    "Good morning, {name}" : "Bos días, {name}",
    "Good afternoon" : "Boas tardes",
    "Good afternoon, {name}" : "Boas tardes, {name}",
    "Good evening" : "Boas noites",
    "Good evening, {name}" : "Boas noites, {name}",
    "Hello" : "Hello",
    "Hello, {name}" : "Ola, {name}",
    "Happy birthday 🥳🤩🎂🎉" : "Feliz aniversario 🥳🤩🎂🎉",
    "Happy birthday, {name} 🥳🤩🎂🎉" : "Feliz aniversario, {name} 🥳🤩🎂🎉"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/dashboard/l10n/gl.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Taboleiro",
    "Dashboard app" : "Aplicación de taboleiro",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking." : "Comece o día informado\n\nO Taboleiro de Nextcloud é o seu punto de partida do día, onde atopará unha vista xeral das súas próximas citas, correos-e urxentes, mensaxes de parolas, billetes entrantes, chíos máis recentes e moito máis. A xente pode engadir os trebellos que lles gusten e cambiar o fondo ao seu antollo.",
    "\"{title} icon\"" : "«icona {title}»",
    "Customize" : "Personalizar",
    "Edit widgets" : "Editar trebellos",
    "Get more widgets from the App Store" : "Obter máis trebellos na tenda de aplicacións",
    "Weather service" : "Servizo meteorolóxico",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Para a súa privacidade, o servidor de Nextcloud solicita os datos meteorolóxicos no seu nome para que o servizo meteorolóxico non reciba información persoal.",
    "Weather data from Met.no" : "Datos meteorolóxicos de Met.no",
    "geocoding with Nominatim" : "xeocodificación con Nominatim",
    "elevation data from OpenTopoData" : "datos de elevación de OpenTopoData",
    "Weather" : "Meteoroloxía",
    "Status" : "Estado",
    "Good morning" : "Bos días",
    "Good morning, {name}" : "Bos días, {name}",
    "Good afternoon" : "Boas tardes",
    "Good afternoon, {name}" : "Boas tardes, {name}",
    "Good evening" : "Boas noites",
    "Good evening, {name}" : "Boas noites, {name}",
    "Hello" : "Hello",
    "Hello, {name}" : "Ola, {name}",
    "Happy birthday 🥳🤩🎂🎉" : "Feliz aniversario 🥳🤩🎂🎉",
    "Happy birthday, {name} 🥳🤩🎂🎉" : "Feliz aniversario, {name} 🥳🤩🎂🎉",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! Users can add the widgets they like and change the background to their liking." : "Comece o día informado\n\nO Taboleiro de Nextcloud é o seu punto de partida do día, onde atopará unha vista xeral das súas próximas citas, correos-e urxentes, mensaxes de parolas, billetes entrantes, chíos máis recentes e moito máis. Os usuarios poden engadir os trebellos que lles gusten e cambiar o fondo ao seu antollo."
},
"nplurals=2; plural=(n != 1);");
